@@ -4,7 +4,8 @@ use warnings;
 
 package Dist::Zilla::Plugin::Test::ReportPrereqs;
 # ABSTRACT: Report on prerequisite versions during automated testing
-our $VERSION = '0.018'; # VERSION
+
+our $VERSION = '0.020';
 
 use Dist::Zilla 4 ();
 
@@ -161,6 +162,8 @@ __PACKAGE__->meta->make_immutable;
 #pod An C<include> attribute can be specified (multiple times) to add modules
 #pod to the report.  This can be useful if there is a module in the dependency
 #pod chain that is problematic but is not directly required by this project.
+#pod These modules will be listed in an "Other Modules" section at the end of
+#pod the report.
 #pod
 #pod =head2 exclude
 #pod
@@ -194,7 +197,7 @@ Dist::Zilla::Plugin::Test::ReportPrereqs - Report on prerequisite versions durin
 
 =head1 VERSION
 
-version 0.018
+version 0.020
 
 =head1 SYNOPSIS
 
@@ -236,6 +239,8 @@ register_prereqs
 An C<include> attribute can be specified (multiple times) to add modules
 to the report.  This can be useful if there is a module in the dependency
 chain that is problematic but is not directly required by this project.
+These modules will be listed in an "Other Modules" section at the end of
+the report.
 
 =head2 exclude
 
@@ -293,6 +298,8 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords Brendan Byrd Karen Etheridge Kent Fredric Randy Stauner Yanick Champoux
+
 =over 4
 
 =item *
@@ -401,12 +408,6 @@ INSERT_EXCLUDED_MODULES_HERE
 # Add static prereqs to the included modules list
 my $static_prereqs = do 'INSERT_DD_FILENAME_HERE';
 
-### XXX: Assume these are Runtime Requires
-my $static_prereqs_requires = $static_prereqs->{runtime}{requires};
-for my $mod (@include) {
-    $static_prereqs_requires->{$mod} = 0 unless exists $static_prereqs_requires->{$mod};
-}
-
 # Merge all prereqs (either with ::Prereqs or a hashref)
 my $full_prereqs = _merge_prereqs(
     ( $HAS_CPAN_META ? $cpan_meta_pre->new : {} ),
@@ -428,11 +429,16 @@ my @full_reports;
 my @dep_errors;
 my $req_hash = $HAS_CPAN_META ? $full_prereqs->as_string_hash : $full_prereqs;
 
-for my $phase ( qw(configure build test runtime develop) ) {
+# Add static includes into a fake section
+for my $mod (@include) {
+    $req_hash->{other}{modules}{$mod} = 0;
+}
+
+for my $phase ( qw(configure build test runtime develop other) ) {
     next unless $req_hash->{$phase};
     next if ($phase eq 'develop' and not $ENV{AUTHOR_TESTING});
 
-    for my $type ( qw(requires recommends suggests conflicts) ) {
+    for my $type ( qw(requires recommends suggests conflicts modules) ) {
         next unless $req_hash->{$phase}{$type};
 
         my $title = ucfirst($phase).' '.ucfirst($type);
@@ -482,9 +488,16 @@ for my $phase ( qw(configure build test runtime develop) ) {
             my $ml = _max( map { length $_->[0] } @reports );
             my $wl = _max( map { length $_->[1] } @reports );
             my $hl = _max( map { length $_->[2] } @reports );
-            splice @reports, 1, 0, ["-" x $ml, "-" x $wl, "-" x $hl];
 
-            push @full_reports, map { sprintf("    %*s %*s %*s\n", -$ml, $_->[0], $wl, $_->[1], $hl, $_->[2]) } @reports;
+            if ($type eq 'modules') {
+                splice @reports, 1, 0, ["-" x $ml, "", "-" x $hl];
+                push @full_reports, map { sprintf("    %*s %*s\n", -$ml, $_->[0], $hl, $_->[2]) } @reports;
+            }
+            else {
+                splice @reports, 1, 0, ["-" x $ml, "-" x $wl, "-" x $hl];
+                push @full_reports, map { sprintf("    %*s %*s %*s\n", -$ml, $_->[0], $wl, $_->[1], $hl, $_->[2]) } @reports;
+            }
+
             push @full_reports, "\n";
         }
     }
